@@ -743,7 +743,7 @@ QStringList XliffStorage::sourceFiles(const DocPosition& pos) const
                 else if (contextType == QLatin1String("linenumber"))
                     linenumber = context.text();
                 if (!(sourcefile.isEmpty() && linenumber.isEmpty()))
-                    result.append(sourcefile % ':' % linenumber);
+                    result.append(sourcefile + ':' + linenumber);
 
                 context = context.nextSiblingElement(QStringLiteral("context"));
             }
@@ -781,7 +781,7 @@ QVector<Note> XliffStorage::notes(const DocPosition& pos) const
         result.append(note);
         elem = elem.nextSiblingElement(NOTE);
     }
-    qSort(result);
+    std::sort(result.begin(), result.end());
     return result.toVector();
 }
 
