@@ -293,7 +293,7 @@ QByteArray Glossary::generateNewId()
 
     QString authorId(Settings::authorName().toLower());
     authorId.replace(' ', '_');
-    QRegExp rx('^' % authorId % QStringLiteral("\\-([0-9]*)$"));
+    QRegExp rx('^' + authorId + QStringLiteral("\\-([0-9]*)$"));
 
 
     foreach (const QByteArray& id, m_idsForEntriesById) {
@@ -308,7 +308,7 @@ QByteArray Glossary::generateNewId()
     }
 
     if (!busyIdNumbers.isEmpty()) {
-        qSort(busyIdNumbers);
+        std::sort(busyIdNumbers.begin(), busyIdNumbers.end());
         while (busyIdNumbers.contains(idNumber))
             ++idNumber;
     }
